History
=======
0.1.0 (2019-08-21)

* First commit. Github Link: https://github.com/linshuliang/tb-paddle

0.2.0 (2019-08-26)

* Append setup requirements, pillow.

0.3.1 (2019-08-27)

* Fix the bug of session_log.

0.3.2 (2019-09-04)

* Optimize the display effect of bbox.

* Append setup requirements - moviepy, which is necessary for API `add_video`.

0.3.3 (2019-09-05)

* Fix the bug of Paddle Graph.

0.3.4 (2019-09-12)

* modify the logging config.

* add RecordReader and Event\_File\_loader.

0.3.5 (2019-09-12)

* add SummaryReader

0.3.6 (2019-09-19)

* modify the limitation of tag.

0.3.7 (2019-12-25)

* Append new API `hparams_api` to support TensorBoard DashBoard `HParams`.

0.3.8 (2019-12-30)

* Fix the bug of forgotten module `time`.

0.3.9 (2020-1-5)

* add support for internal hdfs, not released to outsides.

0.4.0

* delete setup requirement - `moviepy`, users who need to use `add_video` must `pip install moviepy` by themselves.

